Index: trunk/psLib/test/collections/tst_psBitSet_05.c
===================================================================
--- trunk/psLib/test/collections/tst_psBitSet_05.c	(revision 960)
+++ trunk/psLib/test/collections/tst_psBitSet_05.c	(revision 965)
@@ -10,6 +10,6 @@
  *  @author  Ross Harman, MHPCC
  *
- *  @version $Revision: 1.3 $  $Name: not supported by cvs2svn $
- *  @date  $Date: 2004-05-18 19:22:34 $
+ *  @version $Revision: 1.4 $  $Name: not supported by cvs2svn $
+ *  @date  $Date: 2004-06-10 00:28:36 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -28,6 +28,6 @@
     // Test A - Create two psBitSets
     printPositiveTestHeader(stdout,"psBitSet", "Create two psBitSets of different size");
-    psBitSet* bs1 = psBitSetAlloc(3);
-    psBitSet* bs2 = psBitSetAlloc(5);
+    psBitSet* bs1 = psBitSetAlloc(24);
+    psBitSet* bs2 = psBitSetAlloc(40);
     binOut = psBitSetToString(bs1);
     printf("%s\n", binOut);
@@ -41,5 +41,5 @@
     // Test B - Attempt OR with psBitsets, should get error
     printNegativeTestHeader(stdout, "psBitSet", "Attempt OR with psBitsets", "psBitSet sizes not the same", 0);
-    psBitSet* outbs = psBitSetAlloc(3);
+    psBitSet* outbs = psBitSetAlloc(24);
     outbs = psBitSetOp(outbs, bs1, "OR", bs2);
     printFooter(stdout, "psBitSet", "Attempt OR with psBitsets", true);
Index: trunk/psLib/test/collections/tst_psBitSet_06.c
===================================================================
--- trunk/psLib/test/collections/tst_psBitSet_06.c	(revision 960)
+++ trunk/psLib/test/collections/tst_psBitSet_06.c	(revision 965)
@@ -12,6 +12,6 @@
  *  @author  Ross Harman, MHPCC
  *
- *  @version $Revision: 1.5 $  $Name: not supported by cvs2svn $
- *  @date  $Date: 2004-06-09 21:29:56 $
+ *  @version $Revision: 1.6 $  $Name: not supported by cvs2svn $
+ *  @date  $Date: 2004-06-10 00:28:43 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -30,6 +30,6 @@
     // Test A - Create two psBitSets
     printPositiveTestHeader(stdout,"psBitSet", "Create two psBitSets");
-    psBitSet* bs1 = psBitSetAlloc(3);
-    psBitSet* bs2 = psBitSetAlloc(3);
+    psBitSet* bs1 = psBitSetAlloc(24);
+    psBitSet* bs2 = psBitSetAlloc(24);
     binOut = psBitSetToString(bs1);
     printf("%s\n", binOut);
@@ -44,5 +44,5 @@
     printNegativeTestHeader(stdout,"psBitSet", "Perform invalid binary operation",
                             "Invalid psBitMask binary operation", 0);
-    psBitSet* outbs = psBitSetAlloc(3);
+    psBitSet* outbs = psBitSetAlloc(24);
     outbs = psBitSetOp(outbs, bs1, "ZZXOR", bs2);
     printFooter(stdout, "psBitSet", "Perform binary XOR with psBitSets", true);

Index: trunk/psLib/test/collections/tst_psBitSet_01.c
===================================================================
--- trunk/psLib/test/collections/tst_psBitSet_01.c	(revision 960)
+++ trunk/psLib/test/collections/tst_psBitSet_01.c	(revision 965)
@@ -5,12 +5,18 @@
  *  This test driver contains the following tests for psArray test point 1:
  *     A)  Create psBitSet
- *     B)  Set single bit
- *     C)  Test single bit
- *     D)  Free psBitSet
+ *     B)  Set bits
+ *     C)  Test bits
+ *     D)  Attempt to test negative bit
+ *     E)  Attempt to test bit to large
+ *     F)  Attempt to test bit in null BitSet
+ *     G)  Attempt to set negative bit
+ *     H)  Attempt to set bit to large
+ *     I)  Attempt to set bit in null BitSet
+ *     J)  Free psBitSet
  *
  *  @author  Ross Harman, MHPCC
  *
- *  @version $Revision: 1.3 $  $Name: not supported by cvs2svn $
- *  @date  $Date: 2004-05-18 19:22:34 $
+ *  @version $Revision: 1.4 $  $Name: not supported by cvs2svn $
+ *  @date  $Date: 2004-06-10 00:28:23 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -25,4 +31,5 @@
 {
     char *binOut = NULL;
+    psBitSet *tempBs = NULL;
 
 
@@ -30,5 +37,5 @@
     printPositiveTestHeader(stdout,"psBitSet", "Create psBitSet");
     printf("Creating psBitSet with 24 bits...\n");
-    psBitSet* bs = psBitSetAlloc(3);
+    psBitSet* bs = psBitSetAlloc(24);
     binOut = psBitSetToString(bs);
     printf("%s\n\n", binOut);
@@ -37,22 +44,80 @@
 
 
-    // Test B - Set single bit
-    printPositiveTestHeader(stdout, "psBitSet", "Set single bit");
+    // Test B - Set bits
+    printPositiveTestHeader(stdout, "psBitSet", "Set bits");
+    tempBs = bs;
+    printf("Setting first bit...\n");
+    bs = psBitSetSet(bs, 0);
     printf("Setting third bit...\n");
     bs = psBitSetSet(bs, 2);
+    printf("Setting last bit...\n");
+    bs = psBitSetSet(bs, 23);
+    if(bs != tempBs) {
+        printf("Error: Return pointer not equal to output argument pointer\n");
+    }
     binOut = psBitSetToString(bs);
     printf("%s\n\n", binOut);
     psFree(binOut);
-    printFooter(stdout, "psBitSet", "Set single bit", true);
+    printFooter(stdout, "psBitSet", "Set bits", true);
 
 
-    // Test C - Test single bit
-    printPositiveTestHeader(stdout, "psBitSet", "Test single bit");
+    // Test C - Test bits
+    printPositiveTestHeader(stdout, "psBitSet", "Test bits");
+    printf("Testing first bit...\n");
+    printf("Result: %d\n", psBitSetTest(bs, 0));
     printf("Testing third bit...\n");
     printf("Result: %d\n", psBitSetTest(bs, 2));
-    printFooter(stdout, "psBitSet", "Test single bit", true);
+    printf("Testing last bit...\n");
+    printf("Result: %d\n", psBitSetTest(bs, 23));
+    printFooter(stdout, "psBitSet", "Test bits", true);
 
 
-    // Test D - Free psBitSet
+    // Test D - Attempt to test negative bit
+    printNegativeTestHeader(stdout,"psBitSet", "Attempt to test negative bit",
+                            "Bit position too small: -4", 0);
+    if(psBitSetTest(bs, -4)) {
+        printf("Error: Return value should be zero\n");
+    }
+    printFooter(stdout, "psBitSet", "Attempt to test negative bit", true);
+
+
+    // Test E - Attempt to test bit to large
+    printNegativeTestHeader(stdout,"psBitSet", "Attempt to test bit to large",
+                            "Bit position too large: 200", 0);
+    if(psBitSetTest(bs, 200)) {
+        printf("Error: Return value should be zero\n");
+    }
+    printFooter(stdout, "psBitSet", "Attempt to test bit to large", true);
+
+
+    // Test F - Attempt to test bit in null BitSet
+    printNegativeTestHeader(stdout,"psBitSet", "Attempt to test bit in null BitSet",
+                            "Null psBitSet for inBitSet argument", 0);
+    psBitSetTest(NULL, 0);
+    printFooter(stdout, "psBitSet", "Attempt to test bit in null BitSet", true);
+
+
+    // Test G - Attempt to set negative bit
+    printNegativeTestHeader(stdout,"psBitSet", "Attempt to set negative bit",
+                            "Bit position too small: -4", 0);
+    bs = psBitSetSet(bs, -4);
+    printFooter(stdout, "psBitSet", "Attempt to set negative bit", true);
+
+
+    // Test H - Attempt to set bit to large
+    printNegativeTestHeader(stdout,"psBitSet", "Attempt to set bit to large",
+                            "Bit position too large: 200", 0);
+    bs = psBitSetSet(bs, 200);
+    printFooter(stdout, "psBitSet", "Attempt to set bit to large", true);
+
+
+    // Test I - Attempt to set bit in null BitSet
+    printNegativeTestHeader(stdout,"psBitSet", "Attempt to set bit in null BitSet",
+                            "Null psBitSet for inBitSet argument", 0);
+    psBitSetSet(NULL, 0);
+    printFooter(stdout, "psBitSet", "Attempt to set bit in null BitSet", true);
+
+
+    // Test J - Free psBitSet
     printPositiveTestHeader(stdout, "psBitSet", "Free psBitSet");
     psBitSetFree(bs);